@@ -199,9 +199,9 @@ class Conversation:
             new_chat_history = chat_history[truncate_at:]
             self.chat_history = intro + "\n... " + new_chat_history
             # print(len(self.chat_history))
-            return self.chat_history
-        # print(len(chat_history))
-        return chat_history
+        else:
+            self.chat_history = intro + chat_history
+        return self.chat_history
 
     def gen_complete_prompt(self, prompt: str, intro: str = None) -> str:
         """Generates a kinda like incomplete conversation
@@ -265,7 +265,7 @@ class AwesomePrompts:
         if raise_not_found:
             raise KeyError(f"Zero awesome prompt found with key - `{key}`")
 
-    def get_acts(self):
+    def get_acts(self) -> dict:
         """Retrieves all awesome-prompts"""
         with open(self.awesome_prompt_path) as fh:
             prompt_dict = json.load(fh)
